=================
API Documentation
=================

kiacopy package
=============

.. automodule:: kiacopy
    :members:
    :undoc-members:
    :show-inheritance:


kiacopy.solver module
--------------------

.. automodule:: kiacopy.solver
    :members:
    :undoc-members:
    :show-inheritance:


kiacopy.colony module
--------------------

.. automodule:: kiacopy.colony
    :members:
    :undoc-members:
    :show-inheritance:


kiacopy.solution module
--------------------

.. automodule:: kiacopy.solution
    :members:
    :undoc-members:
    :show-inheritance:


kiacopy.circuit module
--------------------

.. automodule:: kiacopy.circuit
    :members:
    :undoc-members:
    :show-inheritance:


kiacopy.state module
--------------------

.. automodule:: kiacopy.state
    :members:
    :show-inheritance:


kiacopy.utils package
===================

.. automodule:: kiacopy.utils
    :members:
    :undoc-members:
    :show-inheritance:


kiacopy.utils.data module
-----------------------

.. automodule:: kiacopy.utils.data
    :members:
    :undoc-members:
    :show-inheritance:


kiacopy.utils.general module
--------------------------

.. automodule:: kiacopy.utils.general
    :members:
    :undoc-members:
    :show-inheritance:


kiacopy.utils.plot module
-----------------------

The plot utility works with the StatsRecorder plugin to generate interesting plots of solver iterations.

.. automodule:: kiacopy.utils.plot
    :members:
    :undoc-members:
    :show-inheritance:

kiacopy.ants package
=============

.. automodule:: kiacopy.ants
    :members:
    :undoc-members:
    :show-inheritance:

kiacopy.ants.ant module
----------------

.. automodule:: kiacopy.ants.ant
    :members:
    :undoc-members:
    :show-inheritance:

kiacopy.ants.sensitiveant module
----------------

.. automodule:: kiacopy.ants.sensitiveant
    :members:
    :undoc-members:
    :show-inheritance:

kiacopy.ants.randomant module
----------------

.. automodule:: kiacopy.ants.randomant
    :members:
    :undoc-members:
    :show-inheritance:
